==> hapi-fhir-structures-r4-3.5.0-sources.jar: org/hl7/fhir/r4/model/codesystems/V3ActUSPrivacyLawEnumFactory.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sun, May 6, 2018 17:51-0400 for FHIR v3.4.0


import org.hl7.fhir.r4.model.EnumFactory;

public class V3ActUSPrivacyLawEnumFactory implements EnumFactory<V3ActUSPrivacyLaw> {

  public V3ActUSPrivacyLaw fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("_ActUSPrivacyLaw".equals(codeString))
      return V3ActUSPrivacyLaw._ACTUSPRIVACYLAW;
    if ("42CFRPart2".equals(codeString))
      return V3ActUSPrivacyLaw._42CFRPART2;
    if ("CommonRule".equals(codeString))
      return V3ActUSPrivacyLaw.COMMONRULE;
    if ("HIPAANOPP".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAANOPP;
    if ("HIPAAPsyNotes".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAAPSYNOTES;
    if ("HIPAASelfPay".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAASELFPAY;
    if ("Title38Section7332".equals(codeString))
      return V3ActUSPrivacyLaw.TITLE38SECTION7332;
    throw new IllegalArgumentException("Unknown V3ActUSPrivacyLaw code '"+codeString+"'");
  }

  public String toCode(V3ActUSPrivacyLaw code) {
    if (code == V3ActUSPrivacyLaw._ACTUSPRIVACYLAW)
      return "_ActUSPrivacyLaw";
    if (code == V3ActUSPrivacyLaw._42CFRPART2)
      return "42CFRPart2";
    if (code == V3ActUSPrivacyLaw.COMMONRULE)
      return "CommonRule";
    if (code == V3ActUSPrivacyLaw.HIPAANOPP)
      return "HIPAANOPP";
    if (code == V3ActUSPrivacyLaw.HIPAAPSYNOTES)
      return "HIPAAPsyNotes";
    if (code == V3ActUSPrivacyLaw.HIPAASELFPAY)
      return "HIPAASelfPay";
    if (code == V3ActUSPrivacyLaw.TITLE38SECTION7332)
      return "Title38Section7332";
    return "?";
  }

    public String toSystem(V3ActUSPrivacyLaw code) {
      return code.getSystem();
      }

}

==> hapi-fhir-structures-r4-3.6.0-sources.jar: org/hl7/fhir/r4/model/codesystems/V3ActUSPrivacyLawEnumFactory.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Thu, Sep 13, 2018 09:04-0400 for FHIR v3.5.0


import org.hl7.fhir.r4.model.EnumFactory;

public class V3ActUSPrivacyLawEnumFactory implements EnumFactory<V3ActUSPrivacyLaw> {

  public V3ActUSPrivacyLaw fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("_ActUSPrivacyLaw".equals(codeString))
      return V3ActUSPrivacyLaw._ACTUSPRIVACYLAW;
    if ("42CFRPart2".equals(codeString))
      return V3ActUSPrivacyLaw._42CFRPART2;
    if ("CommonRule".equals(codeString))
      return V3ActUSPrivacyLaw.COMMONRULE;
    if ("HIPAANOPP".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAANOPP;
    if ("HIPAAPsyNotes".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAAPSYNOTES;
    if ("HIPAASelfPay".equals(codeString))
      return V3ActUSPrivacyLaw.HIPAASELFPAY;
    if ("Title38Section7332".equals(codeString))
      return V3ActUSPrivacyLaw.TITLE38SECTION7332;
    throw new IllegalArgumentException("Unknown V3ActUSPrivacyLaw code '"+codeString+"'");
  }

  public String toCode(V3ActUSPrivacyLaw code) {
    if (code == V3ActUSPrivacyLaw._ACTUSPRIVACYLAW)
      return "_ActUSPrivacyLaw";
    if (code == V3ActUSPrivacyLaw._42CFRPART2)
      return "42CFRPart2";
    if (code == V3ActUSPrivacyLaw.COMMONRULE)
      return "CommonRule";
    if (code == V3ActUSPrivacyLaw.HIPAANOPP)
      return "HIPAANOPP";
    if (code == V3ActUSPrivacyLaw.HIPAAPSYNOTES)
      return "HIPAAPsyNotes";
    if (code == V3ActUSPrivacyLaw.HIPAASELFPAY)
      return "HIPAASelfPay";
    if (code == V3ActUSPrivacyLaw.TITLE38SECTION7332)
      return "Title38Section7332";
    return "?";
  }

    public String toSystem(V3ActUSPrivacyLaw code) {
      return code.getSystem();
      }

}
